@import url("fineprint.css") print;

@import url("bluish.css") projection, tv;

@import 'custom.css';

@import "common.css" screen, projection;

@import url('landscape.css') screen and (orientation:landscape);
