{% extends 'base.html' %}

    {% load static %}
    {% block sb_admin_title %}
        About
    {% endblock sb_admin_title %}
    {% block sb_admin_subheading %}
        <small>MOGI</small>
    {% endblock sb_admin_subheading %}
    {% block sb_admin_breadcrumb %} <a href="{% url "index" %}"><i class="fa fa-fw fa-dashboard"></i> Dashboard</a> {% endblock sb_admin_breadcrumb %}
    {% block sb_admin_breadcrumb_active %}\ About{% endblock sb_admin_breadcrumb_active %}

    {% block content %}

        <div class="row">
                    <div class="col-lg-12">
                        <div class="panel panel-default">
                            <div class="panel-heading">
                                <h3 class="panel-title">Developers & contact</h3>
                            </div>
                            <div class="panel-body">

                                <p>  Thomas N. Lawson (thomas.nigel.lawson@gmail.com) -
                                    <a href="http://www.birmingham.ac.uk/index.aspx">University of Birmingham (UK)</a></p>



                                <div id="morris-area-chart"></div>
                            </div>
                        </div>
                    </div>
        </div>


        <div class="row">
                   <div class="col-lg-12">
                        <div class="panel panel-default">
                            <div class="panel-heading">
                                <h3 class="panel-title">Funding</h3>
                            </div>
                            <div class="panel-body">
                                <p>The MOGI framework was built during the PhD of Thomas N. Lawson funded by <a href="https://nerc.ukri.org/">NERC</a>
                                <a href="http://www.centa.org.uk/">CENTA</a> and CASE funding by <a href="https://academic.oup.com/gigascience">GigaScience</a>
                                </p>


                                <div id="morris-area-chart"></div>
                            </div>
                        </div>
                    </div>
        </div>

                <div class="row">
                   <div class="col-lg-12">
                        <div class="panel panel-default">
                            <div class="panel-heading">
                                <h3 class="panel-title">Licence</h3>
                            </div>
                            <div class="panel-body">

                                <p><a href="https://www.gnu.org/licenses/gpl-3.0.en.html">GPLv3:</a> GNU general public license</p>


                                <div id="morris-area-chart"></div>
                            </div>
                        </div>
                    </div>
        </div>


                <div class="row">
                   <div class="col-lg-12">
                        <div class="panel panel-default">
                            <div class="panel-heading">
                                <h3 class="panel-title">Documentation</h3>
                            </div>
                            <div class="panel-body">

                                <p><a href="https://mogi.readthedocs.io/en/latest/">MOGI developer and user documentation</a> </p>


                                <div id="morris-area-chart"></div>
                            </div>
                        </div>
                    </div>
        </div>



    {% endblock %}
