@media screen, projection {
  html {
    background: #fffef0;
    color: #300;
  }

  body {
    max-width: 35em;
    margin: 0 auto;
  }
}

@media print {
  html {
    background: #fff;
    color: #000;
  }

  body {
    padding: 1in;
    border: 0.5pt solid #666;
  }
}
