{% extends 'base.html' %}
{% load static %}
{% block sb_admin_title %}
      Welcome to the MOGI
{% endblock sb_admin_title %}
{% block sb_admin_subheading %}
       <small>Metabolomics Organisation with Galaxy and ISA</small>
{% endblock sb_admin_subheading %}
{% block sb_admin_breadcrumb %} <a href="{% url "index" %}"><i class="fa fa-fw fa-dashboard"></i> Dashboard</a> {% endblock sb_admin_breadcrumb %}
{% block sb_admin_breadcrumb_active %}{% endblock sb_admin_breadcrumb_active %}

    {% block content %}
        <div class="general">
        <div class="row">
                    <div class="col-lg-3 col-md-6">
                        <div class="panel panel-primary">
                            <div class="panel-heading">
                                <div class="row">
                                    <div class="col-xs-3">
                                        <i class="fa fa-database fa-5x"></i>
                                    </div>
                                    <div class="col-xs-9 text-right">
                                        <div class="huge">{{ dataset_nm }}</div>
                                        <div>Datasets</div>
                                    </div>
                                </div>
                            </div>
                            <a href="{% url "cpeakgroupmeta_summary" %}">
                                <div class="panel-footer">
                                    <span class="pull-left">View Details</span>
                                    <span class="pull-right"><i class="fa fa-arrow-circle-right"></i></span>
                                    <div class="clearfix"></div>
                                </div>
                            </a>
                        </div>
                    </div>
                    <div class="col-lg-3 col-md-6">
                        <div class="panel panel-green">
                            <div class="panel-heading">
                                <div class="row">
                                    <div class="col-xs-3">
                                        <i class="fa fa-tasks fa-5x"></i>
                                    </div>
                                    <div class="col-xs-9 text-right">
                                        <div class="huge">{{ workflow_nm }}</div>
                                        <div>Workflows</div>
                                    </div>
                                </div>
                            </div>
                            <a href="{% url "galaxy_summary" %}">
                                <div class="panel-footer">
                                    <span class="pull-left">View Details</span>
                                    <span class="pull-right"><i class="fa fa-arrow-circle-right"></i></span>
                                    <div class="clearfix"></div>
                                </div>
                            </a>
                        </div>
                    </div>
                    <div class="col-lg-3 col-md-6">
                        <div class="panel panel-yellow">
                            <div class="panel-heading">
                                <div class="row">
                                    <div class="col-xs-3">
                                        <i class="fa fa-sitemap fa-5x"></i>
                                    </div>
                                    <div class="col-xs-9 text-right">
                                        <div class="huge">{{ isa_nm }}</div>
                                        <div>ISA-Projects</div>
                                    </div>
                                </div>
                            </div>
                            <a href="{% url "ilist" %}">
                                <div class="panel-footer">
                                    <span class="pull-left">View Details</span>
                                    <span class="pull-right"><i class="fa fa-arrow-circle-right"></i></span>
                                    <div class="clearfix"></div>
                                </div>
                            </a>
                        </div>
                    </div>
                    <div class="col-lg-3 col-md-6">
                        <div class="panel panel-red">
                            <div class="panel-heading">
                                <div class="row">
                                    <div class="col-xs-3">
                                        <span class="glyphicon glyphicon-font fa-5x"></span>
                                    </div>
                                    <div class="col-xs-9 text-right">
                                        <div class="huge">{{ ann_nm }}</div>
                                        <div>Unique annotations</div>
                                    </div>
                                </div>
                            </div>
                            <a href="{% url "general_summary" %}">
                                <div class="panel-footer">
                                    <span class="pull-left">View Details</span>
                                    <span class="pull-right"><i class="fa fa-arrow-circle-right"></i></span>
                                    <div class="clearfix"></div>
                                </div>
                            </a>
                        </div>
                    </div>
</div>


             <!--<div class="row">-->
                    <!--<div class="col-lg-12">-->
                        <!--<div class="panel panel-default">-->
                            <!--<div class="panel-heading">-->
                                <!--<h3 class="panel-title">Galaxy summary</h3>-->
                            <!--</div>-->
                            <!--<div class="panel-body">-->

                                <!--<div id="morris-area-chart"></div>-->
                            <!--</div>-->
                        <!--</div>-->
                    <!--</div>-->
                <!--</div>-->
             <!--<div class="row">-->
                    <!--<div class="col-lg-12">-->
                        <!--<div class="panel panel-default">-->
                            <!--<div class="panel-heading">-->
                                <!--<h3 class="panel-title">ISA summary</h3>-->
                            <!--</div>-->
                            <!--<div class="panel-body">-->

                                <!--<div id="morris-area-chart"></div>-->
                            <!--</div>-->
                        <!--</div>-->
                    <!--</div>-->
                <!--</div>-->


        </div>

    {% endblock %}
