# -*- coding: utf-8 -*-
from __future__ import unicode_literals
# from django.contrib.auth.models import AnonymousUser, User
# from django.contrib.sessions.middleware import SessionMiddleware
# from django.test import TestCase, RequestFactory, Client
