{% extends 'gfiles/table_with_filter_above.html' %}
{% block sb_admin_title %}Incoming Galaxy Data {% endblock sb_admin_title %}
{% block sb_admin_subheading %} <small>(pre-submission check)</small> {% endblock sb_admin_subheading %}
{% block sb_admin_breadcrumb %}
    <a href="{% url "index" %}"><i class="fa fa-fw fa-dashboard"></i> Dashboard</a>
    / <a href="{% url "general_summary" %}"> Metab Summary</a>
{% endblock sb_admin_breadcrumb %}
{% block sb_admin_breadcrumb_active %} / Incoming Galaxy Data {% endblock sb_admin_breadcrumb_active %}
{% block panel_title %}{% endblock panel_title %}